#========================================================================================
# package      DE_EPAGES::MolliePayments::API::Object::LineItemPaymentMolliePayments
# state        public
# base         DE_EPAGES::ExternalPayment::API::Object::LineItemPaymentExternal
#----------------------------------------------------------------------------------------
# description  object interface for LineItemPaymentMolliePayments.
#========================================================================================
package DE_EPAGES::MolliePayments::API::Object::LineItemPaymentMolliePayments;
use base DE_EPAGES::ExternalPayment::API::Object::LineItemPaymentExternal;

use DE_EPAGES::Trigger::API::Trigger qw ( TriggerHook );

use strict;



#========================================================================================
# function     className
# state        public
#----------------------------------------------------------------------------------------
# syntax       $ClassName = $LineItemPaymentMolliePayments->className;
#----------------------------------------------------------------------------------------
# description  Returns the class name, used for DAL access.
#----------------------------------------------------------------------------------------
# return       $ClassName | class name | String
#========================================================================================
sub className {
    return 'LineItemPaymentMolliePayments';
}



#========================================================================================
# function     insert
# state        private
#----------------------------------------------------------------------------------------
# syntax       $LineItemPaymentMolliePayments = DE_EPAGES::MolliePayments::API::Object::LineItemPaymentMolliePayments->insert($hInfo);
# example      my $Class = LoadClassByAlias('LineItemPaymentMolliePayments');
#               my $LineItemPaymentMolliePayments = $Class->insertObject($hInfo);
#----------------------------------------------------------------------------------------
# description  Insert this info as object, afterwards the hook 'OBJ_InsertLineItemPaymentMolliePayments' is triggered.
#----------------------------------------------------------------------------------------
# input        $Package | class package | string
# input        $hInfo | attributes of new object | ref.hash
# return       $LineItemPaymentMolliePayments | new object | object
# hook         OBJ_InsertLineItemPaymentMolliePayments | hook parameter keys :
#               <ul>
#                 <li>Object        - this object          - object
#                 <li>LineItemPaymentMolliePaymentsID - line item payment id - int
#               </ul>
#========================================================================================
sub insert {
    my ($Package, $hInfo) = @_;

    my $self = $Package->SUPER::insert($hInfo);

    TriggerHook('OBJ_InsertLineItemPaymentMolliePayments', {
        'Object' => $self,
        'LineItemPaymentMolliePaymentsID' => $self->id(),
    });

    return $self;
}



#========================================================================================
# function     delete
# state        private
#----------------------------------------------------------------------------------------
# syntax       $LineItemPaymentMolliePayments->delete;
#----------------------------------------------------------------------------------------
# description  Deletes this object, therefore the hook 'OBJ_DeleteLineItemPaymentMolliePayments' is triggered.
#----------------------------------------------------------------------------------------
# hook         OBJ_DeleteLineItemPaymentMolliePayments | hook parameter keys :
#               <ul>
#                 <li>Object        - this object          - object
#                 <li>LineItemPaymentMolliePaymentsID - line item payment id - int
#               </ul>
#========================================================================================
sub delete {
    my $self = shift;

    TriggerHook('OBJ_DeleteLineItemPaymentMolliePayments', {
        'Object' => $self,
        'LineItemPaymentMolliePaymentsID' => $self->id(),
    });

    $self->SUPER::delete;
    return;
}



#========================================================================================
# function     set
# state        private
#----------------------------------------------------------------------------------------
# syntax       $LineItemPaymentMolliePayments->set($hValues, $LanguageID);
#----------------------------------------------------------------------------------------
# description  This function triggers hooks 'OBJ_BeforeUpdateLineItemPaymentMolliePayments'
#               and 'OBJ_AfterUpdateLineItemPaymentMolliePayments'.
#----------------------------------------------------------------------------------------
# input        $hValues | attribute name => value hash | ref.hash
# input        $LanguageID | (optional; required for localized attributes) language id | int
#----------------------------------------------------------------------------------------
# hook         OBJ_BeforeUpdateLineItemPaymentMolliePayments | hook parameter keys :
#               <ul>
#                 <li>Object        - this object          - object
#                 <li>LineItemPaymentMolliePaymentsID - line item payment id - int
#                 <li>Values        - new values for object - ref.hash
#                 <li>LanguageID    - values of this language will be updated - int
#               </ul>
# hook         OBJ_AfterUpdateLineItemPaymentMolliePayments | hook parameter keys :
#               <ul>
#                 <li>Object        - this object          - object
#                 <li>LineItemPaymentMolliePaymentsID - line item payment id - int
#                 <li>Values        - updated values       - ref.hash
#                 <li>LanguageID    - values updated of this language - int
#               </ul>
#========================================================================================
sub set {
    my $self = shift;
    my ($hValues, $LanguageID) = @_;

    TriggerHook('OBJ_BeforeUpdateLineItemPaymentMolliePayments', {
        'Object'=>$self,
        'Values'=> $hValues,
        'LineItemPaymentMolliePaymentsID' => $self->id(),
        'LanguageID' => $LanguageID,
    });

    $self->SUPER::set($hValues, $LanguageID);

    TriggerHook('OBJ_AfterUpdateLineItemPaymentMolliePayments', {
        'Object'=>$self,
        'Values'=> $hValues,
        'LineItemPaymentMolliePaymentsID' => $self->id(),
        'LanguageID' => $LanguageID,
    });

    return;
}

#========================================================================================
# function     executePayment
# state        private
#----------------------------------------------------------------------------------------
# syntax       $LineItemPaymentMolliePayments->executePayment($hParams);
#----------------------------------------------------------------------------------------
# description  This function directs the payment process.
#               This is called twice, once from Order::Hooks::Basket::OnBasket2OrderExecutePayment, when DoPaymentOnBasket
#               and the other from Order::Hooks::Order::OnOrderExecutePayment, when ! DoPaymentOnBasket
#               These are only used for classic checkout, and they are useless for this cartridge, since it doesn't add
#               an extra step after the basket confirmation page.
#               But why not use it to interrupt the basket process? Well, in Base, the merchant dictates whether to pay
#               on basket or order. If basket, this will interrupt properly, but if on order, the basket will have already been
#               converted to an order, and that we cannot allow! *.~
#               We need our own UI_Basket2Order hookz
#----------------------------------------------------------------------------------------
# input        $hValues | environment information
#                       <ul>
#                           <li>Basket - basket object (optional)</li>
#                           <li>Servlet - servlet handling the current request</li>
#                           <li>Order - order object (optional)</li>
#                       </ul>
#                   | ref.hash
#========================================================================================
sub executePayment {
    my $self = shift;
    my ($hParams) = @_;

    #$self->updateOnExecute($hParams);

    #my $ViewAction =
    #  $hParams->{'Servlet'}->vars('IsMobile') ? 'MobileSF-ViewPaymentMolliePayments' : 'ViewPaymentMolliePayments';

    # show payment template
    #my $Object = $hParams->{'Order'} // $hParams->{'Basket'};
    #Error(
    #    'INVALID_FORM',
    #    {
    #        'ViewVars' => {
    #            'FormError'    => 0,
    #            'ViewObjectID' => $Object->id,
    #        },
    #        'ViewAction' => $ViewAction
    #    }
    #);

    return;
}

1;