#========================================================================================
# §package      DE_EPAGES::MolliePayments::Hooks::Basket
# §state        public
# §description  Additional hook functions for Basket hooks
#========================================================================================
package DE_EPAGES::MolliePayments::Hooks::Basket;

use strict;
use DE_EPAGES::Core::API::Error qw ( Error );
use DE_EPAGES::MolliePayments::UI::BasketOrder;
use DE_EPAGES::MolliePayments::API::PaymentStatusService;
use DE_EPAGES::MolliePayments::API::Constants qw (
    LINE_ITEM_PAYMENT_MOLLIE_PAYMENTS
);

#========================================================================================
# §function     OnUI_Basket2Order
# §state        public
#----------------------------------------------------------------------------------------
# §syntax       OnUI_Basket2Order( $hParams );
#----------------------------------------------------------------------------------------
# §description  Interrupt the basket2order process for classic, if the payment is ours
#                   and when the payment is not yet successful
#----------------------------------------------------------------------------------------
# §input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>Order - order object</li>
#                   <li>Options - options hash</li>
#               </ul> | ref.hash.*
#========================================================================================
sub OnUI_Basket2Order {
    my ($hParams) = @_;

    my $Object = $hParams->{'Basket'};
    my $Servlet = $hParams->{'Servlet'};
    my $PaymentLineItem = $Object->container->get('Payment');

    return unless $PaymentLineItem && $PaymentLineItem->instanceOf(LINE_ITEM_PAYMENT_MOLLIE_PAYMENTS);

    $PaymentLineItem->updateOnExecute($hParams);

    my $ViewAction = $Servlet->vars('IsMobile') ? 'MobileSF-ViewOffer' : 'ViewOffer';

    #-- This will redirect to the payment page, if there is an error
    my $Validated = DE_EPAGES::MolliePayments::UI::BasketOrder->ValidateOrderPaymentStatus($Servlet, $PaymentLineItem);

    #-- If there is no error from validation
    if ( $Validated ) {
        #-- Left for convenience! ^.^
    } else {
        #-- Redirect to the basket confirmation page
        Error(
            'INVALID_FORM',
            {
                'ViewVars' => {
                    'FormError'    => 0,
                    'ViewObjectID' => $Object->id,
                },
                'ViewAction' => $ViewAction,
            }
        );
    }
}

1;
