#==============================================================================
# package      DE_EPAGES::MolliePayments::Hooks::Order
# state        private
#==============================================================================
package DE_EPAGES::MolliePayments::Hooks::Order;

use strict;
use DE_EPAGES::MolliePayments::API::Constants qw (
    LINE_ITEM_PAYMENT_MOLLIE_PAYMENTS
);
use DE_EPAGES::MolliePayments::API::PaymentStatusService;

#========================================================================================
# function     OnOrderCreated
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnOrderCreated($hParams);
#----------------------------------------------------------------------------------------
# description  API_OrderCreated triggered, send requests to Mollie API to update Mollie
#               order and payment name descriptions
#               Triggered for both classic/individual checkout
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>Order
#               </ul> | ref.hash.*
#========================================================================================
sub OnOrderCreated {
    my ($hParams) = @_;
    my $Order = $hParams->{'Order'};

    my $Container = $Order->container();
    return unless defined $Container;
    my $LineItemPayment = $Container->get('Payment');
    return unless defined $LineItemPayment;
    return unless ( $LineItemPayment->instanceOf(LINE_ITEM_PAYMENT_MOLLIE_PAYMENTS) );

    DE_EPAGES::MolliePayments::API::PaymentStatusService->updateMollieOrderName($Order, $LineItemPayment);
    DE_EPAGES::MolliePayments::API::PaymentStatusService->updateMolliePaymentName($Order, $LineItemPayment);

    return;
}

1;
