#==============================================================================
# package      DE_EPAGES::ShoppingList::UI::Shop
# state        private
#==============================================================================
package DE_EPAGES::ShoppingList::UI::Shop;
use base qw( DE_EPAGES::Presentation::UI::Object );

use strict;
use DE_EPAGES::Core::API::Url qw (ParseQueryString );
use DE_EPAGES::ShoppingList::API::ShoppingList qw (AddProductToShoppingList GetUnityShoppingList);
use MIME::Base64 qw(decode_base64);

#==============================================================================
# Event handlers
#==============================================================================

sub UnityViewShoppingList {
    my $self = shift;
    my ($Servlet) = @_;
    my $Shop = $Servlet->object();
    my $User = $Servlet->user();

    my $ProductGUID;
    my $Quantity;
    my $CustomizedText;
    my $LineItemGUID;

    if($Servlet->params('LastViewActionParameters')){
        my $Base64EncParameters = $Servlet->params('LastViewActionParameters');
        my $hValues = ParseQueryString(decode_base64($Base64EncParameters),'utf-8');
        $ProductGUID = $hValues->{'ProductGUID'}->[0];
        $Quantity = $hValues->{'Quantity'}->[0];
        $CustomizedText = $hValues->{'CustomizedText'}->[0];
        $LineItemGUID = $hValues->{'LineItemGUID'}->[0];
    }

    if( defined $User and (not $User->get('IsAnonymous')) ) {
        # add the product to the users shopping list
        if ($ProductGUID){
            my $ShoppingList = GetUnityShoppingList($User);
            my $Product = $Shop->loadObjectByGuid($ProductGUID, 'Product');
            AddProductToShoppingList($ShoppingList, $Product, $Shop, {
                'Quantity'     => $Quantity,
                'LineItemGUID' => $LineItemGUID,
                'CustomizedTextUnity'    => $CustomizedText,
                'User'         => $User,
            });
        }

        $Servlet->vars('ObjectID', $User->id);
        $Servlet->vars('ViewAction', 'UnityViewUserShoppingList');
        return $Servlet->doAction('UnityViewUserShoppingList');

    } else {

        $Servlet->vars('ObjectID', $Shop->id);
        $Servlet->vars('ViewAction', 'UnityViewMyAccount');
        return $Servlet->doAction('UnityViewMyAccount');
    }

}

1;

