#========================================================================================
# package      DE_EPAGES::Zettle::API::Constants
# state        private
#----------------------------------------------------------------------------------------
# description  constants for cartridge
#========================================================================================
package DE_EPAGES::Zettle::API::Constants;
use base Exporter;

use strict;

our @EXPORT_OK = qw (
    INTERNAL_CARTRIDGE_NAME
    ZETTLE_OBJECT_ALIAS
    ZETTLE_ENVIRONMENT_CLASS
    ALLOWED_EXPORT_INTERVALS
    APP_SCOPES
    API_PARTNER_ID
    API_MAX_NAME_LENGTH
    API_MAX_DESCRIPTION_LENGTH
    API_MAX_VARIATIONS_PER_PRODUCT
    API_IMAGE_FORMAT
    ZETTLE_BASIC_ATTRIBUTES
    %INITIAL_EXPORT_STATUS
    VALIDATION_TOKEN_KEY
    ZETTLE_HOME_URL
    ZETTLE_ATTRIBUTES_PROFILE
    ZETTLE_IMAGE_PROFILE
    ZETTLE_PRICE_PROFILE
    WAIT_INTERVAL_AFTER_DELETE
    ZETTLE_TAXATION_TYPE_NONE
    ZETTLE_TAXATION_TYPE_VAT
    ZETTLE_TAXATION_TYPE_SALES_TAX
    ZETTLE_TAXATION_MODE_INCLUSIVE
    ZETTLE_TAXATION_MODE_EXCLUSIVE
);

# This name is used to load objects from database (DON'T CHANGE!)
use constant INTERNAL_CARTRIDGE_NAME => 'Zettle';

# Name of the shop attribute which references the environment object (DON'T CHANGE!)
use constant ZETTLE_OBJECT_ALIAS => 'Zettle';

# Name of class that stores Zettle-related information (DON'T CHANGE!)
use constant ZETTLE_ENVIRONMENT_CLASS => 'ZettleEnvironment';

# Valid export intervals for 'Update interval' selection in Scheduled Export section
use constant ALLOWED_EXPORT_INTERVALS => [ 1, 3, 7, 30 ];

# See "iZettle Partner Integrations: Solution Documentation" page 27, section 4.3.3. Permission Scopes
# Scope parameter: https://github.com/iZettle/api-documentation/blob/master/authorization.adoc#ask-the-user-to-authorize-the-client
use constant APP_SCOPES => qw(
    READ:USERINFO
    READ:PRODUCT
    WRITE:PRODUCT
);

# Identifier provided by Simona Pappalardo from PayPal via email
use constant API_PARTNER_ID => 'epages';

use constant API_MAX_NAME_LENGTH => 256;
use constant API_MAX_DESCRIPTION_LENGTH => 1024;
# See DE_EPAGES/Zettle/Documents/API/ZettleAPI-MaxVariationsPerProduct.md
# See https://developer.zettle.com/docs/api/product-library/concepts/product-library-data
use constant API_MAX_VARIATIONS_PER_PRODUCT => 99;
# Format of image to be exported to Zettle (must match ZETTLE_IMAGE_PROFILE)
# If there's a need to export a different format you must create the associated LastUpdateProfile
# By default, oOnly 'ImageLarge' profile is available with regards to images
use constant API_IMAGE_FORMAT => 'ImageLarge';

# Basic product fields to monitor for changes in order to update LastUpdateProfiles.
# See also build methods in DE_EPAGES::Zettle::API::WebService::DTO::DTOFactory to get a grasp on field parsing.
use constant ZETTLE_BASIC_ATTRIBUTES => (
    qw (
        Name
        Description
        ManufacturerSKU
        UPCEAN
        TaxClass
    )
);

our %INITIAL_EXPORT_STATUS = (
    'FAILED' => -1,
    'PENDING' => 0,
    'RUNNING' => 1,
    'COMPLETED' => 2,
);

use constant VALIDATION_TOKEN_KEY => 'ValidationToken';

use constant ZETTLE_HOME_URL => 'https://www.zettle.com';

# LastUpdateProfile used to keep track of changes in product attributes of interest for Zettle export
use constant ZETTLE_ATTRIBUTES_PROFILE => 'ZettleAttributes';
# LastUpdateProfile used to keep track of changes in product image for Zettle export
use constant ZETTLE_IMAGE_PROFILE => 'ImageLarge';
# LastUpdateProfile used to keep track of changes in product prices for Zettle export
use constant ZETTLE_PRICE_PROFILE => 'ListPrice';

# Zettle has a known bug when performing initial export after deleting products from Zettle. We need to wait the specified number of seconds
use constant WAIT_INTERVAL_AFTER_DELETE => 5;

# ZETTLE TAXATION TYPES: see DE_EPAGES/Zettle/Documents/API/ZettlePartnerDocumentation-Extracts.md, section 4.4.1.1. Taxation Types
# This constant indicates that Zettle merchant account doesn't apply VAT or sales tx to the product prices.
use constant ZETTLE_TAXATION_TYPE_NONE => 'NONE';
# This constant indicates that Zettle merchant account is configured to use country-specific VAT rates
use constant ZETTLE_TAXATION_TYPE_VAT => 'VAT';
# This constant indicates that Zettle merchant account is configured to use merchant-specific VAT rates
use constant ZETTLE_TAXATION_TYPE_SALES_TAX => 'SALES_TAX';
# This constant indicates that Zettle merchant account is configured to include tax in the prices
use constant ZETTLE_TAXATION_MODE_INCLUSIVE => 'INCLUSIVE';
# This constant indicates that Zettle merchant account is configured to exclude tax in the prices
use constant ZETTLE_TAXATION_MODE_EXCLUSIVE => 'EXCLUSIVE';

1;
