# CONTENT
This document contains relevant information regarding Zettle API imposing a limit on the number of
variations per product.

## Variations per product API limit
From <a href="product-library-recommendations">(1)</a>:
> You can only assign up to 99 variants to a product

Same limit is stated in <a href="product-library-relationships">(2)</a>:
> A product contains maximum 99 variants.

Contrary to what we read in API error response:
> "developerMessage": "Invalid variant size. Max: 300"

However, we clarified with Zettle and they said we should stick to the <strong>99 variants limit</strong>.

## Behaviour of integration
Our Zettle integration will enforce API limits and we'll do a best effort when merchant doesn't comply with the requirements.

The behaviour for the different cases is the following:
- <a href="product-library-recommendations">(a)</a> If a product is created with more variations than Zettle API permits, product won't be exported to Zettle.
- <a href="product-library-recommendations">(b)</a> If a product was exported to Zettle and merchant adds a number of variations that go past the limit then all these new variations won't be exported to Zettle.
  However, any subsequent modifications in any of the variations that were already exported will be synced to Zettle.
- <a href="product-library-recommendations">(c)</a> If any product reachs a state where number of variations are over the limit, the only thing the merchant can do to export the product is reduce the number of variations under the limit.<br/>
Once number of variations comply with API limits, product and all of its variations will be processed and sent to Zettle in the following export.

# REFERENCES
From Zettle developer documentation:
1. <a name="product-library-recommendations"></a>Product library - [Recommendations and limits](https://developer.zettle.com/docs/api/product-library/concepts/product-library-concept#recommendations-and-limits).
2. <a name="product-library-relationships"></a>Product library - [Relationships](https://developer.zettle.com/docs/api/product-library/concepts/product-library-data#relationships).